%COMPARACIÓN ESPECTRAL.
%function [stat,dm]=speccom(rav1,av0,lastdm)
%Entradas:
%rav1:predicción de los valores de autocorrelación.
%av0:ACF de las cuatro tramas anteriores interpolados.
%lastdm:distorsión media anterior.
%Salidas:
%stat:valor booleano que indica un estado.
%dm:distorsión media.
function [stat,dm]=speccom(rav1,av0,lastdm)
thresh=0.05;
dm=sum([1 2 2 2 2 2 2 2 2].*rav1.*av0)/av0(1);
difference=abs(dm-lastdm);
if(difference<thresh)
   stat=1;
else
   stat=0;
end